@@ -184,15 +184,12 @@ def all_to_intermediary(filename_or_input, schema=None):
         if all(isinstance(e, str) for e in filename_or_input):
             return line_iterator_to_intermediary(filename_or_input)
 
-    # try to read DB URI.
+    # try to read DB URI might raise ArgumentError.
     try:
         make_url(filename_or_input)
         return database_to_intermediary(filename_or_input, schema=schema)
     except ArgumentError:
-        pass
-
-    msg = "Cannot process filename_or_input {}".format(input_class_name)
-    raise ValueError(msg)
+        raise ValueError("Cannot process filename_or_input {}".format(input_class_name))
 
 
 def get_output_mode(output, mode):
